@@ -15,17 +15,32 @@ from builtins import range, zip
 from collections import namedtuple
 import pytest
 import numpy as np
-import matplotlib
-matplotlib.use('Agg')
+
+try:
+    import matplotlib
+except ImportError:
+    has_matplotlib = False  # OK to run tests without matplotlib
+else:
+    has_matplotlib = True
+    matplotlib.use('Agg')  # but if matplotlib is installed, use Agg
+
+try:
+    import numba
+except ImportError:
+    has_numba = False
+else:
+    has_numba = True
+
 
 import fretbursts.background as bg
 import fretbursts.burstlib as bl
 import fretbursts.burstlib_ext as bext
-import fretbursts.burst_plot as bplt
 from fretbursts import loader
 from fretbursts import select_bursts
 from fretbursts.ph_sel import Ph_sel
 from fretbursts.phtools import phrates
+if has_matplotlib:
+    import fretbursts.burst_plot as bplt
 
 
 # data subdir in the notebook folder
@@ -97,6 +112,19 @@ def list_array_allclose(list1, list2):
 # Test functions
 #
 
+
+def test_bg_compatlayer_for_obsolete_attrs():
+    d = load_dataset_1ch(process=False)
+    attrs = ('bg_dd', 'bg_ad', 'bg_da', 'bg_aa',
+             'rate_m', 'rate_dd', 'rate_ad', 'rate_da', 'rate_aa')
+    for attr in attrs:
+        with pytest.raises(RuntimeError):
+            getattr(d, attr)
+    _alex_process(d)
+    for attr in attrs:
+        assert isinstance(getattr(d, attr), list)
+
+
 def test_ph_times_compact(data_1ch):
     """Test calculation of ph_times_compact."""
     def isinteger(x):
@@ -156,7 +184,7 @@ def test_bg_calc(data):
     assert 'bg_auto_th_us0' in data
     assert 'bg_auto_F_bg' in data
     assert 'bg_th_us_user' not in data
-    
+
     data.calc_bg(bg.exp_fit, time_s=30, tail_min_us='auto', F_bg=1.7,
                  fit_allph=False)
     streams = [s for s in data.ph_streams if s != Ph_sel('all')]
@@ -285,6 +313,12 @@ def test_burst_search_py_cy(data):
     data.burst_search(pure_python=False)
     assert np.all(num_bursts1 == data.num_bursts)
     assert mburst1 == data.mburst
+    data.burst_search(L=30, pure_python=True)
+    mburst1 = [b.copy() for b in data.mburst]
+    num_bursts1 = data.num_bursts
+    data.burst_search(L=30, pure_python=False)
+    assert np.all(num_bursts1 == data.num_bursts)
+    assert mburst1 == data.mburst
 
 def test_burst_search_constant_rates(data):
     """Test python and cython burst search with constant threshold."""
@@ -297,32 +331,44 @@ def test_burst_search_constant_rates(data):
     assert np.all(num_bursts1 == data.num_bursts)
     assert mburst1 == data.mburst
 
+def test_burst_search_L(data):
+    """Test burst search with different L arguments."""
+    data.burst_search(L=10)
+    for bursts in data.mburst:
+        assert (bursts.counts >= 10).all()
+    num_bursts1 = data.num_bursts
+    data.burst_search(L=30)
+    for bursts in data.mburst:
+        assert (bursts.counts >= 30).all()
+    assert np.all(num_bursts1 > data.num_bursts)
+
 def test_burst_search_with_no_bursts(data):
     """Smoke test burst search when some periods have no bursts."""
     # F=600 results in periods with no bursts for the us-ALEX measurement
     # and in no bursts at all for the multi-spot measurements
     data.burst_search(m=10, F=600)
 
-def test_stale_fitter_after_burst_search(data):
-    """Test that E/S_fitter attributes are deleted on burst search."""
-    data.burst_search(L=10, m=10, F=7, ph_sel=Ph_sel(Dex='Dem'))
-    bplt.dplot(data, bplt.hist_fret)  # create E_fitter attribute
-    if data.ALEX:
-        bplt.dplot(data, bplt.hist_S)  # create S_fitter attribute
+if has_matplotlib:
+    def test_stale_fitter_after_burst_search(data):
+        """Test that E/S_fitter attributes are deleted on burst search."""
+        data.burst_search(L=10, m=10, F=7, ph_sel=Ph_sel(Dex='Dem'))
+        bplt.dplot(data, bplt.hist_fret)  # create E_fitter attribute
+        if data.ALEX:
+            bplt.dplot(data, bplt.hist_S)  # create S_fitter attribute
 
-    data.burst_search(L=10, m=10, F=7, ph_sel=Ph_sel(Dex='Aem'))
-    assert not hasattr(data, 'E_fitter')
-    if data.ALEX:
-        assert not hasattr(data, 'S_fitter')
+        data.burst_search(L=10, m=10, F=7, ph_sel=Ph_sel(Dex='Aem'))
+        assert not hasattr(data, 'E_fitter')
+        if data.ALEX:
+            assert not hasattr(data, 'S_fitter')
 
-    bplt.dplot(data, bplt.hist_fret)  # create E_fitter attribute
-    if data.ALEX:
-        bplt.dplot(data, bplt.hist_S)  # create S_fitter attribute
+        bplt.dplot(data, bplt.hist_fret)  # create E_fitter attribute
+        if data.ALEX:
+            bplt.dplot(data, bplt.hist_S)  # create S_fitter attribute
 
-    data.calc_fret()
-    assert not hasattr(data, 'E_fitter')
-    if data.ALEX:
-        assert not hasattr(data, 'S_fitter')
+        data.calc_fret()
+        assert not hasattr(data, 'E_fitter')
+        if data.ALEX:
+            assert not hasattr(data, 'S_fitter')
 
 def test_burst_search(data):
     """Smoke test and bg_bs check."""
@@ -568,44 +614,45 @@ def test_phrates_mtuple(data):
         assert (rates == (m - 1 - phrates.default_c) / delays).all()
         assert (phrates.mtuple_rates_t(phc, m) == t_rates).all()
 
-def test_phrates_kde(data):
-    d = data
-    tau = 5000  # 5000 * 12.5ns = 6.25 us
-    for ph in d.iter_ph_times():
-        # Test consistency of kde_laplace_nph and (kde_laplace, kde_rect)
-        rates = phrates.kde_laplace(ph, tau)
-        nrect = phrates.kde_rect(ph, tau*10)
-        ratesl, nph = phrates.nb.kde_laplace_nph(ph, tau)
-        assert (rates == ratesl).all()
-        assert (nph == nrect).all()
+if has_numba:
+    def test_phrates_kde(data):
+        d = data
+        tau = 5000  # 5000 * 12.5ns = 6.25 us
+        for ph in d.iter_ph_times():
+            # Test consistency of kde_laplace_nph and (kde_laplace, kde_rect)
+            rates = phrates.kde_laplace(ph, tau)
+            nrect = phrates.kde_rect(ph, tau*10)
+            ratesl, nph = phrates.nb.kde_laplace_nph(ph, tau)
+            assert (rates == ratesl).all()
+            assert (nph == nrect).all()
 
-        # Test consistency of kde_laplace and _kde_laplace_self_numba
-        ratesl2, nph2 = phrates.nb.kde_laplace_self_numba(ph, tau)
-        assert (nph2 == nrect).all()
-        assert (ratesl2 == rates).all()
+            # Test consistency of kde_laplace and _kde_laplace_self_numba
+            ratesl2, nph2 = phrates.nb.kde_laplace_self_numba(ph, tau)
+            assert (nph2 == nrect).all()
+            assert (ratesl2 == rates).all()
 
-        # Smoke test laplace, gaussian, rect with time_axis
-        ratesl = phrates.kde_laplace(ph, tau, time_axis=ph+1)
-        assert ((ratesl >= 0) * (ratesl < 5e6)).all()
-        ratesg = phrates.kde_gaussian(ph, tau, time_axis=ph+1)
-        assert ((ratesg >= 0) * (ratesg < 5e6)).all()
-        ratesr = phrates.kde_rect(ph, tau, time_axis=ph+1)
-        assert ((ratesr >= 0) * (ratesr < 5e6)).all()
+            # Smoke test laplace, gaussian, rect with time_axis
+            ratesl = phrates.kde_laplace(ph, tau, time_axis=ph+1)
+            assert ((ratesl >= 0) * (ratesl < 5e6)).all()
+            ratesg = phrates.kde_gaussian(ph, tau, time_axis=ph+1)
+            assert ((ratesg >= 0) * (ratesg < 5e6)).all()
+            ratesr = phrates.kde_rect(ph, tau, time_axis=ph+1)
+            assert ((ratesr >= 0) * (ratesr < 5e6)).all()
 
-def test_phrates_kde_cy(data):
-    d = data
-    tau = 5000  # 5000 * 12.5ns = 6.25 us
-    for ph in d.iter_ph_times():
-        # Test consistency of kde_laplace_nph and (kde_laplace, kde_rect)
-        ratesg = phrates.nb.kde_gaussian_numba(ph, tau)
-        ratesl = phrates.nb.kde_laplace_numba(ph, tau)
-        ratesr = phrates.nb.kde_rect_numba(ph, tau)
-        ratesgc = phrates.cy.kde_gaussian_cy(ph, tau)
-        rateslc = phrates.cy.kde_laplace_cy(ph, tau)
-        ratesrc = phrates.cy.kde_rect_cy(ph, tau)
-        assert (ratesg == ratesgc).all()
-        assert (ratesl == rateslc).all()
-        assert (ratesr == ratesrc).all()
+    def test_phrates_kde_cy(data):
+        d = data
+        tau = 5000  # 5000 * 12.5ns = 6.25 us
+        for ph in d.iter_ph_times():
+            # Test consistency of kde_laplace_nph and (kde_laplace, kde_rect)
+            ratesg = phrates.nb.kde_gaussian_numba(ph, tau)
+            ratesl = phrates.nb.kde_laplace_numba(ph, tau)
+            ratesr = phrates.nb.kde_rect_numba(ph, tau)
+            ratesgc = phrates.cy.kde_gaussian_cy(ph, tau)
+            rateslc = phrates.cy.kde_laplace_cy(ph, tau)
+            ratesrc = phrates.cy.kde_rect_cy(ph, tau)
+            assert (ratesg == ratesgc).all()
+            assert (ratesl == rateslc).all()
+            assert (ratesr == ratesrc).all()
 
 def test_burst_ph_data_functions(data):
     """Tests the functions that iterate or operate on per-burst "ph-data".
